.import-status {
	margin: 30px 0 20px 0;
	text-align: center;
}

.import-done,
.import-progress {
	font-size: 1.5em;
	display: none;
}

.importing .import-progress,
.importing-done .import-done { display: block; }

.import-action:after {
	clear: both;
	content: "";
	display: table;
}

.import-action button {
	-moz-appearance: none;
	-webkit-appearance: none;
	appearance: none;
	background: none;
	border: none;
	cursor: pointer;
	float: left;
	margin: 0.5%;
	opacity: 1;
	-webkit-transition: .4s opacity;
	-moz-transition: .4s opacity;
	transition: .4s opacity;
	width: 32.333%;
}

.import-action button:hover,
.import-action button:focus,
.import-action button[disabled] {
	opacity: .6;
}

.import-action button[disabled] {
	cursor: default;
}

.import-spinner {
	border: 2px solid rgba(0, 0, 0, 0);
	border-right-color: #ccc;
	border-radius: 100%;
	display: block;
	left: 10px;
	height: 30px;
	margin: 0 auto 20px auto;
	position: relative;
	top: 3px;
	width: 30px;
	-webkit-animation: spinner 1s infinite linear;
	animation: spinner 1s infinite linear;
}

@-webkit-keyframes spinner {
  from {
	-webkit-transform: rotate(0deg);
    transform: rotate(0deg); 
  }

  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); 
  }
}

@keyframes spinner {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}