<?php
/**
 * Theme Footer
 */
?>
	
<footer>

  <div class="footer">
    <div class="wrapper">
      <!-- Social -->
      <div class="wrapper__col">

        <div class="footer__siguenos">
          <h3>Síguenos</h3>
          <ul class="footer__social">
            <li>
              <a href="https://ar.linkedin.com/company/contract-workplaces" target="_blank"><svg
                  xmlns="http://www.w3.org/2000/svg" width="32" height="32" viewBox="0 0 32 32">
                  <path id="Icon_awesome-linkedin" data-name="Icon awesome-linkedin"
                    d="M29.714,2.25H2.279A2.3,2.3,0,0,0,0,4.557V31.943A2.3,2.3,0,0,0,2.279,34.25H29.714A2.3,2.3,0,0,0,32,31.943V4.557A2.3,2.3,0,0,0,29.714,2.25ZM9.671,29.679H4.929V14.407h4.75V29.679ZM7.3,12.321a2.75,2.75,0,1,1,2.75-2.75,2.751,2.751,0,0,1-2.75,2.75ZM27.45,29.679H22.707V22.25c0-1.771-.036-4.05-2.464-4.05-2.471,0-2.85,1.929-2.85,3.921v7.557H12.65V14.407H17.2v2.086h.064a5,5,0,0,1,4.493-2.464c4.8,0,5.693,3.164,5.693,7.279Z"
                    transform="translate(0 -2.25)" fill="#fff" />
                </svg>
              </a>
            </li>
            <li>
              <a href="https://www.facebook.com/contractworkplaces/" target="_blank">
                <svg xmlns="http://www.w3.org/2000/svg" width="16.068" height="30" viewBox="0 0 16.068 30">
                  <path id="Icon_awesome-facebook-f" data-name="Icon awesome-facebook-f"
                    d="M16.624,16.875l.833-5.429h-5.21V7.922a2.715,2.715,0,0,1,3.061-2.933h2.368V.367A28.882,28.882,0,0,0,13.473,0C9.183,0,6.378,2.6,6.378,7.308v4.138H1.609v5.429H6.378V30h5.869V16.875Z"
                    transform="translate(-1.609)" fill="#fff" />
                </svg>
              </a>
            </li>
            <li>
              <a href="https://www.instagram.com/contract_workplaces/" target="_blank">
                <svg xmlns="http://www.w3.org/2000/svg" width="30.007" height="30" viewBox="0 0 30.007 30">
                  <path id="Icon_awesome-instagram" data-name="Icon awesome-instagram"
                    d="M15,9.546a7.692,7.692,0,1,0,7.692,7.692A7.679,7.679,0,0,0,15,9.546Zm0,12.692a5,5,0,1,1,5-5,5.01,5.01,0,0,1-5,5ZM24.8,9.231a1.794,1.794,0,1,1-1.794-1.794A1.79,1.79,0,0,1,24.8,9.231ZM29.9,11.052a8.878,8.878,0,0,0-2.423-6.286,8.937,8.937,0,0,0-6.286-2.423c-2.477-.141-9.9-.141-12.378,0A8.924,8.924,0,0,0,2.523,4.76,8.907,8.907,0,0,0,.1,11.046c-.141,2.477-.141,9.9,0,12.378a8.878,8.878,0,0,0,2.423,6.286,8.948,8.948,0,0,0,6.286,2.423c2.477.141,9.9.141,12.378,0a8.878,8.878,0,0,0,6.286-2.423A8.937,8.937,0,0,0,29.9,23.423c.141-2.477.141-9.894,0-12.371ZM26.7,26.081a5.063,5.063,0,0,1-2.852,2.852c-1.975.783-6.661.6-8.843.6s-6.875.174-8.843-.6a5.063,5.063,0,0,1-2.852-2.852c-.783-1.975-.6-6.661-.6-8.843s-.174-6.875.6-8.843A5.063,5.063,0,0,1,6.158,5.543c1.975-.783,6.661-.6,8.843-.6s6.875-.174,8.843.6A5.063,5.063,0,0,1,26.7,8.395c.783,1.975.6,6.661.6,8.843S27.479,24.113,26.7,26.081Z"
                    transform="translate(0.005 -2.238)" fill="#fff" />
                </svg>
              </a>
            </li>
            <li>
              <a href="https://www.youtube.com/user/ContractWorkplaces" target="_blank"><svg
                  xmlns="http://www.w3.org/2000/svg" width="38.4" height="27" viewBox="0 0 38.4 27">
                  <path id="Icon_awesome-youtube" data-name="Icon awesome-youtube"
                    d="M38.648,8.725a4.825,4.825,0,0,0-3.395-3.417c-2.995-.808-15-.808-15-.808s-12.008,0-15,.808A4.825,4.825,0,0,0,1.852,8.725c-.8,3.014-.8,9.3-.8,9.3s0,6.289.8,9.3a4.753,4.753,0,0,0,3.395,3.362c2.995.808,15,.808,15,.808s12.008,0,15-.808a4.753,4.753,0,0,0,3.395-3.362c.8-3.014.8-9.3.8-9.3s0-6.289-.8-9.3ZM16.323,23.737V12.318l10.036,5.71L16.323,23.737Z"
                    transform="translate(-1.05 -4.5)" fill="#fff" />
                </svg>
              </a>
            </li>
          </ul>
          <ul class="footer__menu">
            <li>
              <a href="https://eticacontract.lineaseticas.com/" target="_blank">Línea ética</a>
            </li>
            <li>
              <a href="https://contractworkplaces.com/web/terminos-y-condiciones/" target="_blank">Términos y
                condiciones</a>
            </li>
            <li>
              <a href="https://contractworkplaces.com/web/contacto-contract-workplaces/">Dónde estamos</a>
            </li>
          </ul>
        </div>
      </div>
      <!-- Newsletter -->
      <div class="wrapper__col align-r">
        <div class="footer__newsletter">
          <h3>Suscríbete a<br />
            nuestro newsletter</h3>
          <a href="javascript:void(0)" class="footer__newsletter_button">
            <svg xmlns="http://www.w3.org/2000/svg" width="44.826" height="35.558" viewBox="0 0 44.826 35.558">
              <path id="Icon_simple-minutemailer" data-name="Icon simple-minutemailer"
                d="M8.346,4.055l7.33,7.1L10.5,20.278l10.92-1.751L26.4,29.262,47.514,4.479Zm7.92,11.633,3.395-5.364L39.627,6.139,16.266,15.688Z"
                transform="translate(-9.167 10.014) rotate(-17)" fill="#fff" />
            </svg>
          </a>
        </div>
        <!-- Search -->
        <div class="footer__search">
          <form action="https://contractworkplaces.com/web/" method="get" data-form="submit" role="search">
            <span class="screen-reader-text">Search for:</span>
            <input name="s" type="text" value="" title="Search for:">
            <button type="submit" class="search-submit"><i class="fa fa-search"></i></button>
          </form>
          <svg xmlns="http://www.w3.org/2000/svg" width="30" height="30" viewBox="0 0 30 30">
            <g id="Icon_feather-search" data-name="Icon feather-search" transform="translate(-3 -3)">
              <path id="Trazado_56" data-name="Trazado 56"
                d="M27.947,16.224A11.724,11.724,0,1,1,16.224,4.5,11.724,11.724,0,0,1,27.947,16.224Z" fill="none"
                stroke="#fff" stroke-linecap="round" stroke-linejoin="round" stroke-width="3" />
              <path id="Trazado_57" data-name="Trazado 57" d="M31.35,31.35l-6.375-6.375"
                transform="translate(-0.471 -0.471)" fill="none" stroke="#fff" stroke-linecap="round"
                stroke-linejoin="round" stroke-width="3" />
            </g>
          </svg>
        </div>
      </div>
    </div>
      <!-- Legales -->
      <div class="wrapper">
        <div class="legales">
          <small>Al entrar a este sitio Ud está aceptando los <a
              href="https://contractworkplaces.com/web/terminos-y-condiciones/" target="_blank">Términos y
              Condiciones</a> y
            las <a href="https://contractworkplaces.com/web/terminos-y-condiciones/">Políticas
              de Protección
              de Bases de Datos</a> de Contract Workplaces. Copyright @ Contract Workplaces. Todos los derechos
            reservados.</small>
        </div>
      </div>
    </div>

  <a href="#" class="link--top">
    <svg xmlns="http://www.w3.org/2000/svg" width="60" height="60" viewBox="0 0 60 60">
      <g id="Icon_ionic-ios-arrow-dropup" data-name="Icon ionic-ios-arrow-dropup"
        transform="translate(12.625 10.625)">
        <path id="Trazado_37" data-name="Trazado 37"
          d="M10.378,21.185a1.362,1.362,0,0,1,0-1.92l6.729-6.708a1.356,1.356,0,0,1,1.87-.042l6.63,6.609a1.355,1.355,0,1,1-1.912,1.92L18,15.434l-5.7,5.759A1.356,1.356,0,0,1,10.378,21.185Z"
          transform="translate(-0.608 2.213)" fill="#666" />
        <g id="Elipse_34" data-name="Elipse 34" transform="translate(-12.625 -10.625)" fill="none" stroke="#535353"
          stroke-width="2">
          <circle cx="30" cy="30" r="30" stroke="none" />
          <circle cx="30" cy="30" r="29" fill="none" />
        </g>
      </g>
    </svg>
  </a>

</footer>

<div class="widget-contact">
	<a href="https://contractworkplaces.com/web/contacto-contract-workplaces/#contactanos">
		<img src="https://contractworkplaces.com/web/wp-content/uploads/general/widget-contact-icon.svg" alt="Hablemos">
		<img src="https://contractworkplaces.com/web/wp-content/uploads/general/widget-contact.svg" alt="Contacto"
			 class="widget-contact__title">
	</a>
</div>
 

<div class="modal modal--newsletter">
  <div class="modal__close close--newsletter">
    <svg xmlns="http://www.w3.org/2000/svg" width="28.243" height="28.243" viewBox="0 0 28.243 28.243">
      <g id="icon_close" data-name="close" transform="translate(488.621 -23.379)">
        <line id="line_1" data-name="line 1" x2="24" y2="24" transform="translate(-486.5 25.5)" fill="none"
          stroke="#fff" stroke-linecap="round" stroke-width="2" />
        <line id="line_2" data-name="line 2" x1="24" y2="24" transform="translate(-486.5 25.5)" fill="none"
          stroke="#fff" stroke-linecap="round" stroke-width="2" />
      </g>
    </svg>
  </div>
  <div class="modal__container">
    <?php echo do_shortcode( '[contact-form-7 id="5528" title="Formulario - Newsletter"]' ); ?>
  </div>
</div>


<script>
	// Newsletter
	const triggerNewsletter = document.querySelector('.footer__newsletter_button');
	const closeNewsletter = document.querySelector('.close--newsletter');

	triggerNewsletter.addEventListener('click', function () {
		event.preventDefault();
		document.querySelector('body').classList.toggle('is--newsletter');
	});

	closeNewsletter.addEventListener('click', function () {
		document.querySelector('body').classList.toggle('is--newsletter');
	});
</script>



	</div>

	<?php wp_footer(); ?>
<style>li.actividad + li { 
    opacity:0 !important
}</style>
</body>
</html>

<script>


	

	jQuery(".panel-row-style-colortalk-home .so-widget-gfxbucket-title h3.section-title").text("¿Listo para crear su próximo proyecto?");


	var claseFinal = "";
    var arrayPais = new Array();
	var arrayInd = new Array();

	jQuery("article").attr("data-type","testimonio").each(function(){

		var estePais = jQuery(this).attr("data-pais");
		var estaIndustria = jQuery(this).attr("data-industria");



            if  (estePais!= ""){

                if (jQuery.inArray(estePais, arrayPais) != -1) {
                
                    //echo "Existe esta variable".$ano;
                
                }else{

                 //echo "no existe";
                  arrayPais.push(estePais);
                }
            }

               if  (estaIndustria!= ""){

                if (jQuery.inArray(estaIndustria, arrayInd) != -1) {
                
                    //echo "Existe esta variable".$ano;
                
                }else{

                 //echo "no existe";
                  arrayInd.push(estaIndustria);
                }
            }


            arrayPais.sort();
            arrayInd.sort();

	});



	var optionsIndustria = "";
	var optionsPais = "";

	for(i=0; i < arrayInd.length ; i++){

		optionsIndustria += "<option>"+ arrayInd[i]+"</option>";

	}

	for(i=0; i < arrayPais.length ; i++){

		optionsPais += "<option>"+ arrayPais[i]+"</option>";

	}



	var filterCreator = '<select id="filtroactividad"><option value="0">Actividad</option>'+optionsIndustria+'</select>';

	var filterCreator2 = '<select id="filtroPais"><option value="0">País</option>'+optionsPais+'</select>';

	console.log(arrayInd[0]);

	console.log(arrayPais[0]);

	console.log(filterCreator);


	jQuery("#porIndustriaWp").html(filterCreator);
	jQuery("#porPaisWp").html(filterCreator2);


	if(jQuery("body").hasClass("page-id-209")){


		var listaTestimonios = jQuery(".blog-masonry");
		var paisFlag = false;
		var industriaFlag = false;
		var elementoConClase;
	      
	    listaTestimonios.isotope({
	      itemSelector: ".divContendorArticle",
	   
	    });
	  

	    var palabraActSeleccionada;
	    
    
	    jQuery("#filtroactividad").change(function() {

	    	var selecionado = jQuery("#filtroactividad option:selected").text();

	    	var cantidadPalabras = selecionado.split(' ').length;

	    	if(cantidadPalabras != 1){

	    		palabraActSeleccionada = selecionado.substr(0, selecionado.indexOf(" "));


	    	} else{

	    		var palabraActSeleccionada = selecionado;
	    	}
	    
	    	
	    	

	    	if(palabraActSeleccionada == ".Por"){
	    		palabraActSeleccionada = "*";
	    	}

	    	if(palabraActSeleccionada == ".Medios,"){
	    		palabraActSeleccionada = "Publicidad";
	    	}

	    	 constructClassForFilters(palabraActSeleccionada);
	    	// listaTestimonios.isotope({ filter: palabraActSeleccionada });

	    	 console.log("filtrad: "+claseFinal);



		});

 	   jQuery("#FiltroButton2").click(function(){
 	   		event.preventDefault();

 	   			jQuery("#filtroPais").val('0');
		   	jQuery("#filtroactividad").val('0');
		   	
		  
		    listaTestimonios.isotope({ filter: "*" });
		
		  });

	  


	    function constructClassForFilters(str){

			var dataClass = str;


			claseFinal = claseFinal+"."+dataClass;

		}




	     jQuery("#FiltroButton").click(function(){
	     	event.preventDefault();
	     	var actividadOption = jQuery( "#filtroactividad option:selected" ).text();
		    var paisOption = jQuery( "#filtroPais option:selected" ).text();

	     	var classFinal = "";
		      
		      if(paisOption!="Por país"){

		      	paisOption = "."+paisOption;
		        classFinal += paisOption;

		      }
		  
		      if(actividadOption!="Por industria"){

		      	var cantidadPalabras = actividadOption.split(' ').length;

		    	if(cantidadPalabras != 1){

		    		var palabraAct = actividadOption.substr(0, actividadOption.indexOf(" "));


		    	} else{

		    		var palabraAct = actividadOption;
		    	}
			       
		   
		        palabraAct = "."+palabraAct;
		        classFinal +=palabraAct;

		      }


		      console.log(paisOption);
		      console.log(actividadOption);
		      console.log("esos son los filtros");
		      console.log(classFinal);

		      listaTestimonios.isotope({ filter: classFinal });

		      listaTestimonios.on( 'arrangeComplete',
			  function( event, filteredItems ) {
			    console.log( 'Isotope arrange completed on ' +
			      filteredItems.length + ' items' );
			  }
			);


	    });


	
	}

	if(jQuery("body").hasClass("page-id-323")){
  var notFound = false;


		 var largoObjetosFiltrados ;

		var barraFiltros = jQuery( ".filtrosWp" );
		jQuery( ".filtrosWp" ).remove();

		jQuery( ".page-spacing .site" ).css("padding-top","7.5em");

		jQuery( "#filtrosRowWP" ).append(barraFiltros);


		 jQuery(".filtrosWp").append(jQuery(".fixed-top"));
  		 var filteredFlag = false;
		





	var	elementoAnterior ="";
	var	elementoAnterior2 ="";

	  var listaCasos = jQuery("#rowsCasos");

	      
	    listaCasos.isotope({
	      itemSelector: "tr",
	      layoutMode: "vertical"
	    });
	  

	
		  	 var grid = jQuery(".portfolio-masonry-spacing");
		    
			    grid.isotope({
			      itemSelector: ".portfolio-item",
			      layoutMode: "fitRows"
			    });


			grid.isotope({ filter:  ".pagina1"});
			listaCasos.isotope({ filter:  ".pagina1"});


	   		jQuery(".botonGrilla").click(function(){

    			  event.preventDefault();
    			  
    			  var esteElemento = jQuery(this);

    			  if(elementoAnterior!=""){

    			  	elementoAnterior.removeClass("activeFilterPage");
    			  }

    			  esteElemento.addClass("activeFilterPage");

    			  var filtro = jQuery(this).attr("data-page");



	    		  filtro = "."+filtro;
	    		  pageActual = filtro;

    			  console.log("filtre"+filtro);


    			grid.isotope({ filter:  filtro});

    			elementoAnterior = jQuery(this);



			  
    		});

    		jQuery(".botonTabla").click(function(){

    			  
    			  var esteElemento = jQuery(this);

    			  if(elementoAnterior2!=""){

    			  	elementoAnterior2.removeClass("activeFilterPage");
    			  }

    			  esteElemento.addClass("activeFilterPage");

    			  var filtro = jQuery(this).attr("data-page");


	    		  filtro = "."+filtro;
	    		  pageActual = filtro;

    			  console.log("filtre"+filtro);


    			listaCasos.isotope({ filter:  filtro});

    			elementoAnterior2 = jQuery(this);



			  
    		});


    		


		   jQuery("#FiltroButton2").click(function(){

		   	jQuery("#filtropais").val('0');
		   	jQuery("#filtroactividad").val('0');
		   	jQuery("#filtroano").val('0');

		   	    console.log("Limpie filtre");

		   	      if(notFound){
		      	//jQuery("#resulBusqueda").css("display","none");
		      	
		      	jQuery( "#pg-323-2").css("display","block");
		      	notFound = false;

		      }

		    grid.isotope({ filter: ".pagina1" });
		    listaCasos.isotope({ filter: ".pagina1" });
		    

		
           
            jQuery("#paginadorWp").css("display","block");
            jQuery("#paginadorWp2").css("display","block");

              if(filteredFlag){

		          console.log("aqui2"+elementoConClase);

		           if(largoObjetosFiltrados>1){



			     	    elementoConClase.classList.remove("largeItem");
			          	console.log("removi la clasesss");

		          }
				    			
    		 }
    			






		  });



    jQuery("#FiltroButton").click(function(){

		    console.log("arranco el filtro")  

    		if(filteredFlag){

		          console.log("Elementos"+elementoConClase);

		           if(largoObjetosFiltrados>1){

			     	    elementoConClase.classList.remove("largeItem");
			     	    elementoConClase.classList.remove("largeItemOnGrid");
			          	console.log("removidas la clase");

		          }
				    			
    		 }

		
		      var paisOption = jQuery( "#filtropais option:selected" ).text();
		      var actividadOption = jQuery( "#filtroactividad option:selected" ).text();
		      var anoOption = jQuery( "#filtroano option:selected" ).text();

		      var pageActual = ".pagina1";
		      var classFinal = "";

		      if(notFound){
		      	//jQuery("#resulBusqueda").css("display","none");
		      	jQuery( "#pg-323-2").css("display","block");
		      	notFound = false;

		      }

		      /*
		      if(anoOption!="AÑO"){

		      	anoOption = "."+anoOption;

		        classFinal +=anoOption;

		      }*/

		      if(paisOption!="PAÍS"){

		      	paisOption = "."+paisOption;	
		        classFinal += paisOption;

		      }
		  
		      if(actividadOption!="ACTIVIDAD"){
		       
		        var palabraAct =  actividadOption.split(" ").pop();


		        palabraAct = "."+palabraAct;

		        classFinal += palabraAct;

		      }


		     console.log(classFinal);


		     grid.isotope({ filter: classFinal });
		     listaCasos.isotope({ filter: classFinal });

		     jQuery("#paginadorWp").css("display","none");
		      jQuery("#paginadorWp2").css("display","none");

    		 filteredFlag = true;

		  });


		    var iso = grid.data('isotope');


		     grid.on( 'arrangeComplete',
			  	
			  	function( event, filteredItems ) {

				    console.log( 'Se termino el filtrado ' +  filteredItems.length + ' items');
				     largoObjetosFiltrados = filteredItems.length;

					if(filteredFlag){

				          console.log("Elementosss"+elementoConClase);

				           if(largoObjetosFiltrados>1){

					     	    elementoConClase.classList.remove("largeItem");
					     	    elementoConClase.classList.remove("largeItemOnGrid");
					          	console.log("limpiamos antes de cargar");

				          }
						    			
		    		 }

		    		if(largoObjetosFiltrados == 0){

		    			var paisOption = jQuery( "#filtropais option:selected" ).text();
		     			var actividadOption = jQuery( "#filtroactividad option:selected" ).text();
		     			//var anoOption = jQuery( "#filtroano option:selected" ).text();
		    			
		    			var classResultados = "";

		    			if(paisOption!="PAÍS" && actividadOption!="ACTIVIDAD" ){
		    				var paisSelected = paisOption;
					      	paisOption = "."+paisOption;	
					        classResultados += paisOption;


					     	//jQuery("#resulBusqueda").css("display","block");
					     	//jQuery("#resulBusqueda .filtroSelected").text(paisSelected);

					     	jQuery( "#pg-323-2").css("display","none");

					      /* else if(actividadOption!="ACTIVIDAD"){
		       				
		       				var actividadSelected = actividadOption;
					        var palabraAct = actividadOption.split(" ").pop();

					        palabraAct = "."+palabraAct;
					        classResultados += palabraAct;


					     	//jQuery("#resulBusqueda").css("display","block");
					     	//jQuery("#resulBusqueda .filtroSelected").text(actividadSelected);
					     	jQuery( "#pg-323-2").css("display","none");



					      }*/

					     

					    	 //if(largoObjetosFiltrados == 0)

						     if(notFound){


						     }else{
						     	 grid.isotope({ filter: classResultados });
				   				 listaCasos.isotope({ filter: classResultados });

				   				 notFound = true;
	   				

						     }
				    	
		   				}


				    };


				   
				    if(largoObjetosFiltrados>1){


					    for(i=0; i<largoObjetosFiltrados; i++){

					    	var esteElemento = iso.filteredItems[i].element;

					    	esteElemento.classList.remove("largeItem");
					    	esteElemento.classList.remove("largeItemOnGrid");

					    	if(i==2){

					    		if (notFound == false){
					    			esteElemento.className += "largeItem ";
					    		}else{


					    		}
					    		
					    	};
					       

					       	 elementoConClase = iso.filteredItems[2].element;

					       	 console.log("aqui"+elementoConClase);


					    }

				    } 

			  });


	};

</script>