/* Remove Site Origin Page Builder Plugin Preview Button */
body .siteorigin-widget-preview { display: none !important; }

#optionsframework .group > h3 {
	margin-bottom: 40px;
}

#optionsframework form .section {
	margin-bottom: 20px;
	padding: 0 23px;
}

#optionsframework .section-info .heading {
	border-bottom: 1px solid #ddd;
	font-size: 1.1em;
	margin: 0;
	padding-bottom: 10px;
}

#optionsframework .explain {
	float: right !important;
	width: 38% !important;
	text-align: left !important;
}

.redux-container {
	max-width: 1170px;
}

.color-transparency-check { display: none !important; }

.admin-color-fresh #redux-header {
	background-color: #f4f4f4;
	background-size: cover;
	border-bottom: 1px solid #ddd;
}

.redux-container #redux-header .display_header,
#redux-header h2 {
	color: #222;
	font-weight: 300;
	position: relative;
	z-index: 2;
}

@media screen and (max-width: 1124px) {
	.redux-sidebar .redux-group-menu li a {
		padding: 10px 4px 25px 14px;
	}	
}

.gfxbucket-meta-option {
	padding: 15px 5px 20px 5px;
}

.gfxbucket-meta-option:hover {
	background-color: #F9F9F9;
}

.gfxbucket-meta-option + .gfxbucket-meta-option {
	border-top: 1px solid #eee;
}

#gfxbucket-meta-box .gfxbucket-meta-heading {
	border-bottom: 1px solid #EEE;
	color: #222;
	font-size: 1.2em;
	margin-top: 20px;
	padding: 10px 5px;
}

.gfxbucket-meta-option label {
	cursor: default;
	display: inline-block;
	font-weight: 900;
	margin-bottom: 15px;
	width: 30%;
}

.gfxbucket-meta-option p {
	color: #666;
	font-size: 12px;
	margin: 10px 0 0 0;
}

.gfxbucket-meta-option select,
.gfxbucket-meta-option input {
	min-width: 100%;
	position: relative;
	top: 5px;
}

@media(min-width: 550px) {
	.gfxbucket-meta-option label {
		margin-bottom: 0;
	}
	
	.gfxbucket-meta-option select {
		min-width: 100px;
	}

	.gfxbucket-meta-option input {
		min-width: 250px;
	}

	.gfxbucket-meta-option p {
		margin: 0;
		width: 28%;
	}
}