<?php
/**
 * 404 Page Template
 */
get_header(); ?>

	<div class="container">
		<main id="main" class="site-main" role="main">
			<article class="error-404">
					<h2 class="error-404-title"><?php _e( 'Uh oh! (404 Error)', 'dropout' ); ?></h2>
					<h4 class="error-404-subtitle"><?php _e( 'We are really sorry but the page you requested is missing :(', 'dropout' ); ?></h4>
					<a class='btn-md btn' href="javascript:javascript:history.go(-1)">&leftarrow;  <?php _e('Go Back','dropout'); ?></a>
			</article>
		</main>
	</div>

<?php get_footer(); ?>