<?php if ( is_active_sidebar( 'sidebar' ) ) : ?>
	<div id="widget-area" class="sidebar col-md-3 col-md-offset-1" role="complementary">
		<?php dynamic_sidebar( 'sidebar' ); ?>
	</div><!-- .widget-area -->
<?php endif; ?>