/* =WordPress Core
-------------------------------------------------------------- */
.alignnone {
    margin: 5px 20px 20px 0;
}

.aligncenter,
div.aligncenter {
    display: block;
    margin: 5px auto 5px auto;
}

.alignright {
    float:right;
    margin: 5px 0 20px 20px;
}

.alignleft {
    float: left;
    margin: 5px 20px 20px 0;
}

a img.alignright {
    float: right;
    margin: 5px 0 20px 20px;
}

a img.alignnone {
    margin: 5px 20px 20px 0;
}

a img.alignleft {
    float: left;
    margin: 5px 20px 20px 0;
}

a img.aligncenter {
    display: block;
    margin-left: auto;
    margin-right: auto
}

.wp-caption {
    max-width: 100%;
    padding: 5px 3px 10px;
}

.wp-caption.alignnone {
    margin: 5px 20px 20px 0;
}

.wp-caption.alignleft {
    margin: 5px 20px 20px 0;
}

.wp-caption.alignright {
    margin: 5px 0 20px 20px;
}

.wp-caption img {
    border: 0 none;
    height: auto;
    margin: 0;
    max-width: 98.5%;
    padding: 0;
    width: auto;
}

.wp-caption .wp-caption-text {
    font-size: 16px;
    margin: 0;
    padding: 12px 0;
}

/* Text meant only for screen readers. */
.screen-reader-text {
	clip: rect(1px, 1px, 1px, 1px);
	position: absolute !important;
	height: 1px;
	width: 1px;
	overflow: hidden;
}

.screen-reader-text:focus {
	background-color: #f1f1f1;
	border-radius: 3px;
	box-shadow: 0 0 2px 2px rgba(0, 0, 0, 0.6);
	clip: auto !important;
	color: #21759b;
	display: block;
	font-size: 14px;
	font-size: 0.875rem;
	font-weight: bold;
	height: auto;
	left: 5px;
	line-height: normal;
	padding: 15px 23px 14px;
	text-decoration: none;
	top: 5px;
	width: auto;
	z-index: 100000; /* Above WP toolbar. */
}

.gallery-caption, .bypostauthor {  }

.blog-masonry {
	margin-top: -10px;
	padding-top: 10px;
}

.sticky .sticky-header {
	background-image: url('../images/sticky.png');
	background-repeat: no-repeat;
	border-bottom: 2px solid #e1e1e1;
	color: #222;
	font-size: 12px;
	font-weight: 600;
	margin-bottom: 10px;
	padding: 5px 0 25px 28px;
	text-transform: uppercase;
}

.sticky.has-post-thumbnail .sticky-header {
	margin-bottom: 30px;
}

.blog-masonry .sticky .sticky-header {
	margin: 20px 26px 0;
	padding-bottom: 15px;
}

/* Changes, may require changes in style.css */

/* [start] Blog Post Image Vertical Image Fix */
.blog-post-image { text-align: center; }
.blog-posts .blog-post-image { border: none; }
.blog-posts .blog-post-image img { border: 1px solid #E1E1E1; }
/* [end] Blog Post Image Vertical Image Fix */

/* [start] Blog Post dots fix */
.blog-posts { border-bottom: 1px dotted #B2B2B2; }
.blog-posts:after { display: none; }
/* [end] Blog Post dots fix */

/* [start] Table Styling */
table, th, td { border: 1px solid #E1E1E1; }

th, td {
	border-width: 0 1px 1px 0;
	padding: 0.4em;
}

table {
	border-collapse: separate;
	border-spacing: 0;
	border-width: 1px 0 0 1px;
	margin: 0 0 1.6em;
	table-layout: fixed;
	width: 100%;
}

th { color: #222; }
/* [end] Table Styling */

/* [start] Blog Post Content H4 Fix */
.blog-post-content h4 {
	margin-bottom: 32px;
	margin-top: 64px;
}
/* [end] Blog Post Content H4 Fix */

/* [start] Blockquote fix */
/*body blockquote {
	margin: 28px 0;
}*/
/* [end] Blockquote fix */

/* [start] Headings fix */
h1, h2, h3, h4, h5, h6 {
	line-height: 1.03em;
	font-weight: 700;
}

h1, h2, h3, h4, h5, h6 {
	margin-bottom: 32px;
	margin-top: 64px;
}

h1 { font-size: 48px; }
h2 { font-size: 32px; }
h3 { font-size: 26px; }
h4 { font-size: 21px; }
h5 { font-size: 18px; }
h5 { font-size: 16px; }
h6 { font-size: 14px; }
/* [end] Headings fix */

/* [start] Definition list */
dt { color: #222; }
dd { margin-bottom: 40px; }
/* [end] Definition list */

/* [start] <strong> fix */
strong { color: #222; }
/* [end] <strong> fix */

/* [start] <address> fix */
address {
	font-style: italic;
	margin-bottom: 40px;
}
/* [end] <address> fix */

/* [start] <p> fix */
p { margin-bottom: 20px; }
/* [end] <p> fix */

/* [start] <cite> fix */
cite { font-style: italic; }
/* [end] <cite> fix */

/* [start] <pre> fix */
pre {
	font-size: 16px;
}
/* [end] <pre> fix */

/* [start] image align fix */
img.aligncenter { margin: 40px auto; }
img.alignleft { margin: 0.5em 40px 40px 0; }
img.alignright { margin: 0.5em 0 40px 40px; }
/* [end] image align fix */

/* [start] <code> fix */
code, pre {
	color: #333;
	background-color: #F2F2F2;
	border-color: #E1E1E1;
	border-radius: 0;
}
/* [end] <code> fix */

.nav-sticky.admin-bar .site-header .nav-row {
	position: absolute;
	top: 46px;
}

.nav-bottom.admin-bar .site-header .nav-menu {
	top: 100%;
}

.nav-scroll-active.nav-sticky.admin-bar .site-header .nav-row {
	position: fixed;
	top: 0;
}

@media(min-width: 601px) {
	.nav-sticky.admin-bar .site-header .nav-row,
	.nav-scroll-active.nav-sticky.admin-bar .site-header .nav-row {
		position: fixed;
		top: 46px;
	}

	.page.admin-bar.nav-sticky,
	.blog.admin-bar.nav-sticky,
	.archive.admin-bar.nav-sticky,
	.search.admin-bar.nav-sticky { padding-top: 46px; }
	.admin-bar.nav-default-style-2 .nav-menu { padding-top: 166px; }
	.admin-bar.nav-default-style-2.nav-scroll-active .site-header .nav-menu { padding-top: 126px; }
}

@media(min-width: 783px) {
	.nav-sticky.admin-bar .site-header .nav-row,
	.nav-scroll-active.nav-sticky.admin-bar .site-header .nav-row {
		top: 32px;
	}	

	.page.admin-bar.nav-sticky,
	.blog.admin-bar.nav-sticky,
	.archive.admin-bar.nav-sticky,
	.search.admin-bar.nav-sticky { padding-top: 32px; }
	.admin-bar.nav-default-style-2 .nav-menu { padding-top: 152px; }
	.admin-bar.nav-default-style-2.nav-scroll-active .site-header .nav-menu { padding-top: 112px; }
}

.tp-caption .btn {
	border: 2px solid rgba(0, 0, 0, 0.4);
}

.preloader svg, .preloader img {
	transition: 2s width, 2s height !important;
}

.header-message {
	float: right;
	margin-top: 13px;
}

.clients:after {
	clear: both;
	content: "";
	display: table;
}

@media (min-width: 768px) {
	.counter.counter-col-1 li { width: 100%; }
	.counter.counter-col-2 li { width: 50%; }
	.counter.counter-col-3 li { width: 33.3333%; }
	.counter.counter-col-4 li { width: 25%; }
	.counter.counter-col-5 li { width: 20%; }
	.counter.counter-col-6 li { width: 16.6666%; }
}

.page-nav > ul {
	margin: 0;
	padding: 0;
}

.page-nav span {
	border: 1px solid #E1E1E1;
	display: block;
	padding: 8px 16px;
}

.page-nav span:hover,
.page-nav span.current {
	color: #222;
	border-color: #777;
}

.single-post .site-main > .section-title {
	margin-bottom: 30px;
}

.single-post .site-main > .section-title + .blog-post-author {
	padding-top: 0;
}

.single-post .page-cover + .element {
	padding-top: 0;
}

.single.page-spacing .site-header + .element-spacing {
	margin-top: 20px;
}

.single .sidebar {
	margin-top: 158px;
}

body .section-title {
	text-align: left;
}

.text-center .section-title  {
	text-align: center;
}

.text-right .section-title  {
	text-align: right;
}

body .statement.video {
	padding-bottom: 76px;
	padding-top: 76px;
}

@media (min-width: 768px) {
	body .statement.video {
		padding-bottom: 106px;
		padding-top: 106px;
	}
}

@media (min-width: 992px) {
	body .statement.video {
		padding-bottom: 156px;
		padding-top: 156px;
	}
}

@media (min-width: 1200px) {
	body .statement.video {
		padding-bottom: 206px;
		padding-top: 206px;
	}
}

.icon {
	position: relative;
}

.icon i {
	color: #dbdbdb;
	font-size: 42px;
}

.icon img {
	height: auto;
	width: 42px;
}

.icon.style-2 i {
	font-size: 72px;
}

.icon.style-2 img {
	width: 72px;
}

@media (min-width: 500px) {
	body .icon .icon-image {
		left: 0;
	}
}

.form-group br {
	display: none;
}


/* Form Errors */
input.error, textarea.error,
input.wpcf7-not-valid, textarea.wpcf7-not-valid {
  background-color: #fbdbcf !important;
  border-color: #f3746d !important;
}

label.error, label.success,
span.wpcf7-not-valid-tip, div.wpcf7-validation-errors,
div.wpcf7-mail-sent-ok {
  border-radius: 5px;
  color: #fff;
  display: block;
  font-size: 16px;
  font-weight: 400;
  margin: 0;
  margin-top: 15px;
  padding: 7px 15px;
  width: 100%;
}

label.error,
span.wpcf7-not-valid-tip, div.wpcf7-validation-errors {
  background-color: #e1534f;
  border: 1px solid #a4413e;
}

label.success,
div.wpcf7-mail-sent-ok {
  background-color: #5cb45d;
  border: 1px solid #539854;
}

span.wpcf7-not-valid-tip {
	margin-bottom: 15px;
}

.textwidget > h1,
.textwidget > h2,
.textwidget > h3,
.textwidget > h4,
.textwidget > h5,
.textwidget > h6 {
	line-height: 1.3em;
	font-weight: 600;
	margin-top: 50px;
	text-transform: uppercase;
}

blockquote.style-2 p {
	text-align: center;
}

.panel-group .panel {
	margin-bottom: 0 !important;
}

.page-spacing .site {
	padding-top: 150px;
}

.nav-side.page-spacing .site {
	padding-top: 125px;
}

.background--dark.nav-side .nav-toggle svg {
	stroke: #222;
}

.admin-bar.nav-side.page-spacing .site  {
	padding-top: 165px;
}

.page-spacing-off.nav-sticky .site {
	padding-top: 75px;
}

.nav-sticky-disabled .page-title {
	margin-top: 152px;
}

/* Side navigation breadcrumbs */

.nav-side .page-title {
	margin-top: 75px;
}

.nav-side.admin-bar .page-title {
	margin-top: 121px;
}

@media(min-width: 783px) {
	.nav-side.admin-bar .page-title {
		margin-top: 107px;
	}
}

@media (min-width: 992px) {
	.nav-side .page-title {
		margin-top: 0;
	}

	.nav-side.admin-bar .page-title {
		margin-top: 32px;
	}

	.page-spacing .site {
		padding-top: 210px;
	}

	.nav-side.page-spacing .site,
	.admin-bar.nav-side.page-spacing .site {
		padding-top: 70px;
	}

	.page-spacing-off.nav-sticky .site {
		padding-top: 120px;
	}
}

.section-scroll.page-spacing .site,
.section-scroll.page-spacing-off .site {
	padding-top: 0;
}

/* Section spacing */

.panel-grid-cell {
	margin-bottom: 0 !important;
}

.panel-grid {
	margin-bottom: 40px;
}

@media (min-width: 768px) {
	.panel-grid {
		margin-bottom: 80px;
	}
}

@media (min-width: 992px) {
	.panel-grid {
		margin-bottom: 120px;
	}
}

.panel-grid:last-of-type {
	margin-bottom: 0;
}

/* /Section spacing */

h3.section-title, .statement h3 {
	font-size: 30px;
	padding: 0 30px;
}

.site-footer {
	margin-top: 120px;
	padding-top: 0;
}
.footer-no-spacing .site-footer { margin-top: 0; }

.footer-content { margin-top: 37px; }
.site-footer .copyright { margin-top: 0; }
.site-footer .copyright + .footer-content { margin-top: 37px; }
.site-footer > .container { padding-bottom: 37px; padding-top: 37px; }
li.recentcomments { list-style: none; padding: 0; }
.recentcomments:before { display: none; }
.site-footer .widget_recent_comments a { color: #cbcbcb; }

/* WordPress Comments */

.comment-list {
    margin: 0;
    padding: 0;
}

.comment {
    font-size: 18px;
    list-style: none;
    margin: 0;
    position: relative;
}

.comment:hover > .comment-body .comment-reply-link,
.comment:hover > .comment-body .comment-edit-link {
    opacity: 1;
}

.comment + .comment,
.comment .children {
	border-top: 1px solid #E1E1E1;
	padding-top: 40px;
}

.comment .children {
	margin-bottom: 40px;
	margin-top: 40px;
}

.comment-meta {
    margin-bottom: 20px;
    min-height: 56px;
    padding-left: 80px;
    position: relative;
}

.comment-author,
.comment-author > a {
    color: #222;
	font-size: 20px;
	font-weight: 400;
}

.comment-author .comment-reply-link {
	font-size: 16px;
	font-weight: 300;
}

.comment-metadata {
    color: #ADADAD;
    font-size: 16px;
}

.comment-meta .avatar {
    left: 0;
    position: absolute;
    top: 0;
}

.comment-reply-link,
.comment-edit-link {
    opacity: 0;
    transition: .2s opacity;
}

.nav-scroll.background--dark .header-message {
	color: #fff;
}

.nav-scroll-active.background--dark .header-message {
	color: #777;
}

/* Navigation Level 3 */

@media (min-width: 992px) {
	.nav-desktop .site-header .nav-menu .sub-menu .sub-menu {
		left: 100%;
		margin: 0 0 0 -1px;
		top: 0;
	}

	.nav-desktop .site-header .nav-menu ul > li:hover .sub-menu {
		display: none;
	}

	.nav-desktop .site-header .nav-menu ul > li:hover > .sub-menu {
		display: block;
	}

/*	.nav-desktop.nav-scroll .site-header .nav-menu > ul > li > a  { color: #fff; opacity: 1; }
	.nav-desktop.nav-scroll .site-header .nav-menu > ul > li.menu-item-has-children:before { border-top-color: #fff; }
	.nav-desktop.nav-scroll .site-header .nav-menu > ul > li > a:hover { opacity: .7; }
*/
	.nav-desktop.nav-scroll-active .site-header .nav-menu > ul > li > a  { color: #222; opacity: 1; }
	.nav-desktop.nav-scroll-active .site-header .nav-menu > ul > li.menu-item-has-children:before { border-top-color: #222; }
	.nav-desktop.nav-scroll-active .site-header .nav-menu > ul > li > a:hover { color: #e21737; opacity: 1; }
}

/* Remove submenus on types that do not support them */

.nav-default .sub-menu,
.nav-bottom .sub-menu,
.nav-top .sub-menu,
.nav-side .sub-menu { display: none; }

/* No social nav fix */

.nav-bottom.header-no-social.nav-open .site-header .nav-menu li:nth-of-type(1) {
  bottom: 79px; }
.nav-bottom.header-no-social.nav-open .site-header .nav-menu li:nth-of-type(2) {
  bottom: 151px; }
.nav-bottom.header-no-social.nav-open .site-header .nav-menu li:nth-of-type(3) {
  bottom: 223px; }
.nav-bottom.header-no-social.nav-open .site-header .nav-menu li:nth-of-type(4) {
  bottom: 295px; }
.nav-bottom.header-no-social.nav-open .site-header .nav-menu li:nth-of-type(5) {
  bottom: 367px; }
.nav-bottom.header-no-social.nav-open .site-header .nav-menu li:nth-of-type(6) {
  bottom: 439px; }
.nav-bottom.header-no-social.nav-open .site-header .nav-menu li:nth-of-type(7) {
  bottom: 511px; }
.nav-bottom.header-no-social.nav-open .site-header .nav-menu li:nth-of-type(8) {
  bottom: 583px; }

.nav-top.nav-open .site-header .nav-menu > ul > li:first-of-type {
	top: 79px;
}

.nav-top .site-header .nav-menu > ul > li:first-of-type > a {
	padding-bottom: 21px;
}

/* Logged in */

.nav-top.header-no-social.nav-open.admin-bar .site-header .nav-menu > ul > li:first-of-type {
  top: 111px; }
.nav-top.header-no-social.nav-open.admin-bar .site-header .nav-menu > ul > li:nth-of-type(2) {
  top: 184px; }
.nav-top.header-no-social.nav-open.admin-bar .site-header .nav-menu > ul > li:nth-of-type(3) {
  top: 256px; }
.nav-top.header-no-social.nav-open.admin-bar .site-header .nav-menu > ul > li:nth-of-type(4) {
  top: 328px; }
.nav-top.header-no-social.nav-open.admin-bar .site-header .nav-menu > ul > li:nth-of-type(5) {
  top: 400px; }
.nav-top.header-no-social.nav-open.admin-bar .site-header .nav-menu > ul > li:nth-of-type(6) {
  top: 472px; }
.nav-top.header-no-social.nav-open.admin-bar .site-header .nav-menu > ul > li:nth-of-type(7) {
  top: 544px; }
.nav-top.header-no-social.nav-open.admin-bar .site-header .nav-menu > ul > li:nth-of-type(8) {
  top: 616px; }

.admin-bar.nav-side .site-header,
.admin-bar.nav-sticky-disabled .site-header .nav-row {
	position: absolute;
	top: 46px;
}

.admin-bar.nav-side.page-spacing-off .site {
	padding-top: 46px;
}

@media(min-width: 601px) {
	.admin-bar.nav-side .site-header {
		position: fixed;
	}
}

@media(min-width: 783px) {
	.admin-bar.nav-side .site-header,
	.admin-bar.nav-sticky-disabled .site-header .nav-row {
		top: 32px;
	}

	.admin-bar.nav-side.page-spacing-off .site {
		padding-top: 32px;
	}
}

.single-portfolio .site-footer { margin-top: 0; }
.portfolio-single-description { padding-bottom: 0; }

.portfolio-nav a {
	background-repeat: no-repeat;
	background-size: cover;
	background-position: center;
}

.hover-content h3,
.hover-content h4,
.hover-content h5,
.hover-content h6 {
	margin-top: 0;
}

h3.section-title,
h4.section-title,
h5.section-title,
h6.section-title {
	font-weight: 500;
}

.form-group { margin-bottom: 0; position: relative; }
.form-group + .form-group { margin-top: 15px; }
.form-group .ajax-loader {
	left: 50%;
	margin-left: -8px;
	position: absolute;
	top: 60px;
}

.page-cover h4 {
	font-weight: 400;
	margin-top: 10px;
}

.blog-post-title {
	word-wrap: break-word;
}

.blog-posts header > a {
	display: inline-block;
	max-width: 100%;
	transition: opacity .2s;
}

.blog-posts header > a:hover {
	opacity: .8;
}

@media (min-width: 992px) {
	.nav-side .siteorigin-panels-stretch {
		padding-left: 265px !important;
	}

	.nav-side .portfolio-content .siteorigin-panels-stretch {
		padding-left: 0 !important;
	}
}

.section-title:before {
	display: block; 
	content: " "; 
	margin-top: -125px;
	height: 125px; 
	visibility: hidden; 
}

.title {
	margin-top: -125px;
	padding-top: 162px;
}

.title:before {
	top: 125px;
}

.recent-posts {
	display: block;
	width: 100%;
}

.page-cover, .page-title {
	margin-bottom: 80px;
}

@media (min-width: 992px) {
	.page-cover, .page-title {
		margin-bottom: 120px;
	}
}

.single-post .page-cover {
	margin-bottom: 0;
}

.single-post .site-footer {
	margin-top: 0;
}

.single-post .site-main {
	margin-bottom: 120px;
}

.page-title-heading {
	font-weight: 400;
}

/* Boxed Layout Fix */

@media (min-width: 786px) {
	.boxed .siteorigin-panels-stretch {
		margin: 0 -45px !important;
		padding-left: 0 !important;
		padding-right: 0 !important;
	}

	.boxed .site {
		  max-width: 1000px;
	}

	.boxed .siteorigin-panels-stretch.statement {
		padding-left: 45px !important;
		padding-right: 45px !important;
	}
}

@media(min-width: 1200px) {
	.boxed .siteorigin-panels-stretch {
		margin: 0 -50px !important;
	}

	.boxed .site {
	  max-width: 1210px;
	}

	.boxed .siteorigin-panels-stretch.statement {
		padding-left: 50px !important;
		padding-right: 50px !important;
	}
}

.error-404-subtitle {
	margin-bottom: 40px;
	margin-top: 0;
}

.sidebar .widget:first-of-type .widget-title {
	margin-top: 0;
}

.sidebar .widget-title {
	margin-bottom: 30px;
}

/* Widget and Footer Fixes */

.footer-content p {
	text-align: center;
}

.footer-content .wp-caption.alignnone {
	margin: 0;
}

.site-footer.style-2 .footer-content,
.site-footer .footer-content .widget:first-of-type {
	margin-top: 0;
}

.sidebar .social,
.site-footer.style-1 .social {
	padding: 0;
}

/* Social Widget */

.site-footer.style-1 .social a {
	color: #939393;
}

/* Select field */

select {
	background: none;
	background-image: url('../images/select.png');
	background-repeat: no-repeat;
	background-position: center right;
	border-radius: 0;
	padding: 9px 10px;
}

.site-footer.style-1 select {
	border: 1px solid #2D2D2D;
	color: #939393;
}

/* Contact Info Widget */

.footer-content .widget {
	font-size: 16px;
}

.sidebar .contact-info li,
.site-footer .col-md-3 .contact-info li,
.site-footer .col-md-4 .contact-info li,
.site-footer .col-md-6 .contact-info li {
	display: block;
	margin-left: 0;
	margin-right: 0;
}

.sidebar .contact-info {
	list-style: none;
	margin: 0;
	padding: 0;
}

.sidebar .contact-info li + li {
	margin-top: 10px;
}

.sidebar .contact-info svg {
  fill: #aaa;
  margin-right: 10px;
  position: relative;
  top: 6px;
  stroke: #aaa;
}

.sidebar .contact-info svg.phone {
  height: 21px;
  width: 21px;
}

.sidebar .contact-info svg.mail {
  height: 22px;
  width: 22px;
}

.sidebar .contact-info svg.map-pin {
  height: 21px;
  width: 21px;
}

/* Lists */

.widget ul.children {
	margin-top: 12px;
}

.sidebar .menu,
.site-footer .menu,
.widget_archive ul,
.widget_pages ul,
.widget_meta ul,
.widget_rss ul {
  list-style: none;
  margin: 0;
  padding: 0;
}

.sidebar .menu li + li,
.site-footer .menu li + li,
.widget_archive li + li,
.widget_pages li + li,
.widget_meta li + li,
.widget_rss li + li {
  margin-top: 12px;
}

.sidebar .menu a,
.site-footer .menu a,
.widget_archive a,
.widget_pages a,
.widget_meta a {
  position: relative;
  padding-left: 20px;
}

.sidebar .menu a:before,
.site-footer .menu a:before,
.widget_archive a:before,
.widget_pages a:before,
.widget_meta a:before {
  border-top: 5px solid rgba(0, 0, 0, 0);
  border-bottom: 5px solid rgba(0, 0, 0, 0);
  border-left: 6px solid #B5B5B5;
  content: "";
  left: 0;
  height: 0;
  margin-top: 1px;
  position: absolute;
  top: 50%;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
  -webkit-transition: border-color .2s;
  transition: border-color .2s;
  width: 0;
}

/* Calendar */

.widget_calendar table,
.widget_calendar th,
.widget_calendar td {
	border: none;
	margin: 0;
}

.widget_calendar tfoot {
	display: none;
}

.site-footer.style-1 .widget_calendar caption,
.site-footer.style-1 .widget_calendar tbody td#today,
.site-footer.style-1 .widget_calendar tbody td.today,
.site-footer.style-1 .widget_calendar tbody td a {
	color: #CBCBCB;
}

.widget_calendar tbody td {
	color: #939393;
}

.site-footer.style-1 .widget_calendar #calendar_wrap {
	border-color: #2D2D2D;
}

/* Tagcloud */

.tagcloud a {
	font-size: 16px !important;
}

/* RSS */

.rsswidget {
	font-weight: 600;
	margin-top: 10px;
}

.rss-date {
	display: block;
	font-style: italic;
	margin-bottom: 5px;
}

.widget_rss cite {
	display: block;
	text-align: right;
}

.site-footer.style-2 a,
.site-footer.style-2 {
	color: #777;
}

.site-footer.style-2 .widget-title {
	color: #222;
}

.site-footer.style-2 .widget_search input[type="text"] {
	border-color: #E1E1E1;
}

.site-footer.style-2 .widget_search input[type="text"]:focus {
	border-color: #222;
}

/* Recent Posts */

.widget_recent_entries li {
	padding-left: 0;
}

.widget_recent_entries .post-date {
	background: none;
	color: #777;
	display: block;
	height: auto;
	padding: 0;
	position: static;
	text-align: left;
	width: 100%;
}

/* /Widget and Footer Fixes */

.admin-bar.nav-open .site-header .nav-menu > ul {
	position: relative;
	top: 50px;
}

.admin-bar.nav-bottom.nav-open .site-header .nav-menu > ul {
	top: auto;
}

.admin-bar.nav-open.nav-default-style-2 .site-header .nav-menu > ul {
	position: static;
	top: 0;
}

.site-header .nav-menu .current-menu-item > a {
	color: #e21737 !important;
}

@media (min-width: 992px) {

  .nav-desktop.nav-sticky.nav-scroll-active .site-header .nav-menu > ul > li.menu-item-has-children:before {
    margin-top: -9px; }
  .nav-desktop .site-header .nav-menu > ul > li.menu-item-has-children a {
    padding-right: 22px; }
  .nav-desktop .site-header .nav-menu > ul > li.menu-item-has-children:before {
    border-left: 4px solid transparent;
    border-right: 4px solid transparent;
    border-top: 4px solid #222;
    content: "";
    height: 0;
    margin-top: -12px;
    position: absolute;
    right: 0;
    top: 50%;
    -webkit-transition: all .5s;
            transition: all .5s;
    width: 0; }
}

.page-cover-content .search-submit {
	display: none;
}

.search-error-title {
	line-height: 1.5em;
	margin-bottom: 50px;
	text-align: center;
}

.search-error input[type="text"],
.search-error .widget_search button {
	font-size: 18px;
	padding: 14px 16px;
}

input[type="text"] {
	border-radius: 0;
}

.blog-masonry.row {
	margin-left: -30px;
	margin-right: -30px;
}

.site-footer.style-1 input[type="text"]::-webkit-input-placeholder { color: #939393; }
.site-footer.style-1 input[type="text"]:-moz-placeholder { color: #939393; }
.site-footer.style-1 input[type="text"]::-moz-placeholder { color: #939393; }
.site-footer.style-1 input[type="text"]:-ms-input-placeholder { color: #939393; }

.textwidget h1:first-child,
.textwidget h2:first-child,
.textwidget h3:first-child,
.textwidget h4:first-child,
.textwidget h5:first-child,
.textwidget h6:first-child,
.so-widget-gfxbucket-visual-editor *:first-child {
	margin-top: 0;
}

body {
	overflow-y: scroll;
}

.blog-masonry .blog-post-image img {
	max-height: none !important;
	position: relative;
	width: auto;
}

.blog-masonry .col-md-3 .more,
.blog-masonry .col-md-3 .blog-post-comments-link {
	display: block;
	position: static;
	width: 100%;
}

.blog-masonry .col-md-3 .blog-post-comments-link {
	margin-top: 10px;
}

.portfolio-post-header-content {
	right: 15px;
}

.portfolio-post-header.no-background {
	height: auto;
	margin-top: 120px;
}

@media (min-width: 992px) {
	.portfolio-post-header.no-background {
		margin-top: 160px;
	}
}

.portfolio-content .portfolio-post-header.no-background {
	margin-top: 0;
}

.portfolio-post-header.no-background:before {
	display: none;
}

.portfolio-post-header.no-background .portfolio-post-header-content {
	position: static;
}

.portfolio-post-header.no-background .portfolio-post-header-heading,
.portfolio-post-header.no-background .portfolio-post-header-meta strong {
	color: #222;
}

.portfolio-post-header.no-background .portfolio-post-header-meta,
.portfolio-post-header.no-background .portfolio-post-header-description {
  color: #777;
}

.nav-sticky-disabled .nav-row {
	background-color: #fff;
	border-bottom: 1px solid #E1E1E1;
}

.portfolio-post-header-description {
	font-size: 21px;
}

.portfolio-nav {
	position: relative;
	z-index: 1;
}

.portfolio .hover .hover-content {
	-webkit-transform: translateX(-50%) translateY(-50%);
	        transform: translateX(-50%) translateY(-50%);
}

/* Counter fixes */

@media (min-width: 768px) {
	.counter {
		display: table;
		width: 100%;
	}

	.counter li {
		display: table-cell;
		float: none;
		height: auto;
		vertical-align: top;
	}

	.counter li {
		padding-bottom: 67px;
		padding-top: 67px;
	}
}

@media (max-width: 767px) {
	.counter-image:empty {
		height: 0;
	}
}

.counter-image {
	margin: 0 auto;
	margin-bottom: 21px;
	margin-top: 0 !important;
}

.counter-image i {
	color: #ccc;
	font-size: 42px;
}

.counter-image,
.counter-image img {
	height: 42px;
	width: 42px;
}

.counter-no-image .counter-image {
	display: none;
}

/* Spacing When No Avatar On Posts */

.no-avatar .blog-post-author {
	padding-top: 40px;
}

/* Image Gallery */

.gallery:after {
	clear: both;
	content: "";
	display: table;
}

.gallery br {
	display: none;
}

.gallery-item {
	float: left;
	position: relative;
	width: 100%;
}

.gallery-item a {
	display: block;
	position: relative;
}

.gallery-item a:hover:after,
.gallery-item a:focus:after,
.gallery-item a:hover:before,
.gallery-item a:focus:before {
	opacity: 1;
}

.gallery-item a:hover:before,
.gallery-item a:focus:before {
	transform: translateY(0);
}

.gallery-item img {
	width: 100%;
}

.gallery-caption {
	color: #222;
	padding: 20px;
	text-align: center;
}

.gallery-item a:before,
.gallery-item a:after {
	opacity: 0;
	position: absolute;
	transition: .2s opacity, transform .4s;
}

.gallery-item a:before {
	-webkit-backface-visibility: hidden;
	color: #222;
	content: "\f03e";
	font-family: "FontAwesome";
	font-size: 36px;
	left: 0;
	margin-top: -12px;
	text-align: center;
	top: 50%;
	transform: translateY(50px);
	width: 100%;
	z-index: 2;
}

.gallery-item a:after {
	background-color: rgba(255, 255, 255, .85);
	bottom: 10px;
	content: "";
	left: 10px;
	right: 10px;
	top: 10px;
	z-index: 1;
}

@media(min-width: 500px) {
	.gallery-item { width: 50%; }
}

@media(min-width: 768px) {
	.gallery-item { width: 33%; }
}

@media(min-width: 992px) {
	.gallery-columns-1 .gallery-item { width: 100%; }
	.gallery-columns-2 .gallery-item { width: 50%; }
	.gallery-columns-3 .gallery-item { width: 33.3333%; }
	.gallery-columns-4 .gallery-item { width: 25%; }
	.gallery-columns-5 .gallery-item { width: 20%; }
	.gallery-columns-6 .gallery-item { width: 16.6666%; }
	.gallery-columns-7 .gallery-item { width: 14.2857%; }
	.gallery-columns-8 .gallery-item { width: 12.5%; }
	.gallery-columns-9 .gallery-item { width: 11.1111%; }
}

.featherlight .featherlight-content {
	border: none;
	padding: 65px 0 0 0;
}

.featherlight .featherlight-close {
	border: 1px solid #E1E1E1;
	font-size: 36px;
	height: 65px;
	padding: 20px;
	transition: all .4s;
	width: auto;
}

.featherlight .featherlight-close:hover,
.featherlight .featherlight-close:focus {
	background-color: #222;
	border-color: #222;
	color: #fff;
}

.featherlight-image {
	border-top: 1px solid #E1E1E1;
	margin-top: -1px;
}

.page-title-no-spacing {
	margin-bottom: 0;
}

html, body {
	-ms-overflow-style: scrollbar;
}

.siteorigin-panels-stretch .rev_slider {
	margin: 0 -15px;
}

.site.style-2 .page-nav a,
.site.style-2 .page-nav span {
	background-color: #fff;
}

.site-footer .btn {
  color: #939393;
  border-color: inherit;
  -moz-transition: .4s all;
  -webkit-transition: .4s all;
  transition: .4s all;
}

.site-footer .btn:hover,
.site-footer .btn:focus {
  color: #fff;
}

/* Close elements (title overlap) */

.textwidget,
.panel-group {
	position: relative;
	z-index: 1;
}

/* New version of Revolution Slider */

.rev_slider[data-version*="5."] .hesperiden.tparrows:hover { background: none; }
.rev_slider[data-version*="5."] .hesperiden.tparrows:before { display: none; }

/* New fs */

#fp-nav {
	color: #fff;
}

#fp-nav li {
	list-style: none;
	height: 24px;
	margin: 2px 0;
	position: relative;
}

.fp-tooltip  {
	padding-right: 20px;
	text-align: right;
}

#fp-nav a {
	background-color: rgba(255, 255, 255, 0.4);
	border: 2px solid rgba(255, 255, 255, 0);
	border-radius: 100%;
	display: block;
	height: 9px;
	margin-right: -4px;
	margin-top: 1px;
	position: absolute;
	right: 0;
	top: 50%;
	-moz-transform: translateY(-50%);
	-webkit-transform: translateY(-50%);
	transform: translateY(-50%);
	width: 9px;
	z-index: 1;
}

#fp-nav .active {
	background: none;
	border-color: rgba(255, 255, 255, 0.7);
	height: 15px;
	margin-right: -7px;
	width: 15px;
}

.fp-tooltip {
	opacity: 0;
    -webkit-transition: opacity 0.2s ease-in;
    transition: opacity 0.2s ease-in;
}

#fp-nav a:hover + .fp-tooltip,
#fp-nav .active + .fp-tooltip {
	opacity: 1;
}

.section-fs-content-center,
.section-fs .instagram .col-md-12,
.section-fs .twitter .col-md-12 {
	left: 50%;
	right: auto;
	top: 50%;
	-webkit-transform: translateX(-50%) translateY(-50%);
	-ms-transform: translateX(-50%) translateY(-50%);
	transform: translateX(-50%) translateY(-50%);
}

.section-fs input[type="text"], .section-fs input[type="email"], .section-fs input[type="tel"], .section-fs input[type="number"], .section-fs input[type="password"], .section-fs textarea, .section-fs select {
	border: none;
	border-radius: 0;
}

.section-fs label, .section-fs strong { color: #fff; }
.section-fs h2 { margin-top: 0; }

@media(min-width: 768px) {
	.section-fs h2 + [role="form"] { margin-top: 60px; }
}

.section-fs .instagram,
.section-fs .twitter {
	height: 100%;
}

.section-fs .btn {
	color: #222;
}


.section-fs .statement .btn {
	-webkit-transition: .2s border-color, .2s background-color, .2s color;
	transition: .2s border-color, .2s background-color, .2s color;
}

.section-fs .statement .btn:hover,
.section-fs .statement .btn:focus {
	color: #222;
	opacity: 1;
}

.section-fs-content-advanced {
	padding: 0;
}

.section-fs .section-fs-content-advanced * {
	text-align: inherit;
}

.section-fs-content-advanced {
  	-webkit-transform: none;
  	-ms-transform: none;
  	transform: none;	
}

.section-fs-content-advanced.fs-x-center {
	left: 50%;
  	-webkit-transform: translateX(-50%);
  	-ms-transform: translateX(-50%);
  	transform: translateX(-50%);
}

.section-fs-content-advanced.fs-x-right {
	left: auto;
	right: 0;
}

.section-fs-content-advanced.fs-y-top {
	top: 120px;
}

.section-fs-content-advanced.fs-y-bottom {
	bottom: 0;
	margin-bottom: 35px;
	top: auto;
}

.section-fs-content-advanced.fs-y-center {
	top: 50%;
  	-webkit-transform: translateY(-50%);
  	-ms-transform: translateY(-50%);
  	transform: translateY(-50%);
}

.section-fs-content-advanced.fs-x-center.fs-y-center {
  	-webkit-transform: translateX(-50%) translateY(-50%);
  	-ms-transform: translateX(-50%) translateY(-50%);
  	transform: translateX(-50%) translateY(-50%);
}

.fl-video {
	max-width: 1300px;
	width: 90%;
}

.fl-video .video-wrapper {
	border: none;
	z-index: 0;
}

.fl-iframe-video {
	display: none;
}

.video-wrapper { padding-bottom: 53%; padding-top: 0; }